@@ -2,7 +2,6 @@ library(GGIR)
 context("Chainof5parts")
 test_that("chainof5parts", {
   skip_on_cran()
-  
   Ndays = 2
   create_test_acc_csv(Nmin = Ndays*1440)
   create_test_sleeplog_csv(advanced = FALSE)
@@ -313,7 +312,9 @@ test_that("chainof5parts", {
   sib.cla.sum = rbind(sib.cla.sum, newrow)
   sib.cla.sum = sib.cla.sum[order(sib.cla.sum$sib.onset.time),]
   sib.cla.sum$sib.period[1:11] = 1:11
-  save(L5list, SPTE_end, SPTE_start, sib.cla.sum, tib.threshold, file = rn3[1])
+  part3_guider = "HDCZA"
+  save(L5list, SPTE_end, SPTE_start, sib.cla.sum, tib.threshold, part3_guider,
+       file = rn3[1])
   g.part4(datadir = fn, metadatadir = metadatadir, f0 = 1, f1 = 1,
           idloc = 2, loglocation = c(), do.visual = TRUE,
           outliers.only = FALSE, excludefirstlast = FALSE,
@@ -329,7 +330,7 @@ test_that("chainof5parts", {
   expect_true(dir.exists(dirname))
   expect_true(file.exists(vis_sleep_file))
   expect_that(round(nightsummary$number_sib_wakinghours[1], digits = 4), equals(0))
-  expect_that(round(nightsummary$SptDuration[1], digits = 2), equals(16.14))
+  expect_equal(nightsummary$SptDuration[1], 16.15, tolerance = 0.01)
   expect_true(as.logical(nightsummary$acc_available[1]))
   expect_false(as.logical(nightsummary$sleeplog_used[1]))
   #----------------------------------------------------------------------
